@@ -134,7 +134,10 @@ class AppBuilder(BuilderInterface):
             if repo_path:
                 context_dir = repo_path
                 target_dir = os.path.join(temp_dir, 'build')
-                temp_exe_path = os.path.join(target_dir, build_target or 'release', exe_name)
+                if build_target:
+                    temp_exe_path = os.path.join(target_dir, build_target, 'release', exe_name)
+                else:
+                    temp_exe_path = os.path.join(target_dir, 'release', exe_name)
                 install_command = [cargo_path, 'build', '--release', '--target-dir', target_dir]
             else:
                 context_dir = temp_dir
@@ -150,13 +153,21 @@ class AppBuilder(BuilderInterface):
 
                     self.cargo_build(install_command, cwd=context_dir, env=env)
 
-                    exe_stem = f'{script}-{build_target}' if build_target else script
+                    exe_stem = (
+                        f'{script}-{self.metadata.version}-{build_target}'
+                        if build_target
+                        else f'{script}-{self.metadata.version}'
+                    )
                     exe_path = os.path.join(app_dir, f'{exe_stem}.exe' if on_windows else exe_stem)
                     shutil.move(temp_exe_path, exe_path)
             else:
                 self.cargo_build(install_command, cwd=context_dir, env=base_env)
 
-                exe_stem = f'{self.metadata.name}-{build_target}' if build_target else self.metadata.name
+                exe_stem = (
+                    f'{self.metadata.name}-{self.metadata.version}-{build_target}'
+                    if build_target
+                    else f'{self.metadata.name}-{self.metadata.version}'
+                )
                 exe_path = os.path.join(app_dir, f'{exe_stem}.exe' if on_windows else exe_stem)
                 shutil.move(temp_exe_path, exe_path)
 
