@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import os
 
 
-def locate_file(root, file_name):
+def locate_file(root: str, file_name: str) -> str | None:
     while True:
         file_path = os.path.join(root, file_name)
         if os.path.isfile(file_path):
@@ -9,13 +11,13 @@ def locate_file(root, file_name):
 
         new_root = os.path.dirname(root)
         if new_root == root:
-            return
+            return None
 
         root = new_root
 
 
-def path_to_uri(path):
+def path_to_uri(path: str) -> str:
     if os.sep == '/':
-        return f'file://{os.path.normpath(path)}'
+        return f'file://{os.path.abspath(path)}'
     else:
-        return f'file://{os.path.normpath(path).replace(os.sep, "/")}'
+        return f'file:///{os.path.abspath(path).replace(os.sep, "/")}'
